==> evolution-1.4.11.zip: evolution-1.4.11/assets/modules/docmanager/lang/persian.inc.php <==
<?php
/**
 * Document Manager Module
 * 
 * Purpose: Contains the language strings for use in the module.
 * Author: Mohsen (MotSmart), www.modxcms.ir
 * Language: Persian
 * Date: 2014/02/24
 */
// titles
$_lang['DM_module_title'] = 'مدیریت پرونده';
$_lang['DM_action_title'] = 'انتخاب دستور';
$_lang['DM_range_title'] = 'انتخاب بازه ی شناسه های پرونده';
$_lang['DM_tree_title'] = 'پرونده ها را از درختی انتخاب کنید';
$_lang['DM_update_title'] = 'به روز رسانی شد';
$_lang['DM_sort_title'] = 'ویرایشگر فهرست وب';

// tabs
$_lang['DM_doc_permissions'] = 'سطوح دسترسی پرونده';
$_lang['DM_template_variables'] = 'متغیرهای قالب';
$_lang['DM_sort_menu'] = 'ترتیب دهی فهرست';
$_lang['DM_change_template'] = 'تغییر پوسته یا قالب';
$_lang['DM_publish'] = 'انتشار/تعلیق';
$_lang['DM_other'] = 'مشخصات دیگر';

// buttons
$_lang['DM_close'] = 'بستن مدیریت پرونده';
$_lang['DM_cancel'] = 'بازگشت';
$_lang['DM_go'] = 'برو';
$_lang['DM_save'] = 'ذخیره';
$_lang['DM_sort_another'] = 'فهرست کردن یکی دیگه';

// templates tab
$_lang['DM_tpl_desc'] = 'قالب مورد نظر خود را از جدول زیر انتخاب کنید و سپس شناسه ی پرونده هایی که نیاز به تغییر دارند را مشخص کنید. هم میتوانید بازه ی پرونده ها را مشخص کنید و یا از درختی زیر استفاده کنید.';
$_lang['DM_tpl_no_templates'] = 'پوسته یا قلبی پیدا نشد';
$_lang['DM_tpl_column_id'] = 'شناسه';
$_lang['DM_tpl_column_name'] = 'اسم';
$_lang['DM_tpl_column_description'] = 'توضیحات';
$_lang['DM_tpl_blank_template'] = 'پوسته یا قالب خالی';
$_lang['DM_tpl_results_message'] = 'در صورتیکه نیاز به اعمال تغییرات بیشتری هستید دکمه ی هقب را بزنید. کش وبگاه بطور خودکار پاک شده.';

// template variables tab
$_lang['DM_tv_desc'] = 'شناسه ی پرونده هایی را که نیازمند تغییر است مشخص کنید, هم میتوانید از طریق مشخص کردن بازه ی شناسه انتخاب کنید و یا  از طریق درختی زیر, سپس قالب مورد نیاز را از جدل زیر انتخاب کنید تا متغیرهای قالب بازخوانی شود. مقدار متغیرهای مورد نظر خود را وارد و برای پردازش ارسال کنید.';
$_lang['DM_tv_template_mismatch'] = 'این پرونده از قالب انتخابی استفاده نمی کند.';
$_lang['DM_tv_doc_not_found'] = 'این پرونده در دیتابیس موجود نیست.';
$_lang['DM_tv_no_tv'] = 'هیچ متغیر قالبی برای این پوسته یا قالب یافت نشد.';
$_lang['DM_tv_no_docs'] = 'پرونده ای برای به روز رسانی انتخاب نشده.';
$_lang['DM_tv_no_template_selected'] = 'قالب یا پوسته ای انتخاب نشده.';
$_lang['DM_tv_loading'] = 'در حال بازخوانی متغیرهای قالب ...';
$_lang['DM_tv_ignore_tv'] = 'به این متغیرها اهمیتی داده نشود (متغیرها را با کاما جدا کنید):';
$_lang['DM_tv_ajax_insertbutton'] = 'وارد کردن';

// document permissions tab
$_lang['DM_doc_desc'] = 'گروه پرونده ای مورد نیاز را از جدول زیر انتخاب کنید. در صورت تمایل میتوانید گروه پرونده ای را اضافه یا حذف کنید. سپس شناسه ی پرونده را که بایستی تغیر کند مشخص کنید. همپنین از طریق بازه ی شناسه یا از طریق استفاده از درختی زیر.';
$_lang['DM_doc_no_docs'] = 'گروه پرونده ای یافت نشد.';
$_lang['DM_doc_column_id'] = 'شناسه';
$_lang['DM_doc_column_name'] = 'اسم';
$_lang['DM_doc_radio_add'] = 'اضافه کردن گروه پرونده ای';
$_lang['DM_doc_radio_remove'] = 'حذف گروه پرونده ای';

$_lang['DM_doc_skip_message1'] = 'پرونده با شناسه ی';
$_lang['DM_doc_skip_message2'] = 'جزو گروه پرونده ای انتخاب شده است (بی اثر)';

// sort menu tab
$_lang['DM_sort_pick_item'] = 'لطفا روت سایت یا پرونده ی دست بالا را تمایل به ترتیب دهی دارید را از درختی اصلی پرونده ها کلیک کنید.';
$_lang['DM_sort_updating'] = 'به روز رسانی ...';
$_lang['DM_sort_updated'] = 'به روز شد';
$_lang['DM_sort_nochildren'] = 'پرونده ی دست بالا هیپ پرونده ی زیر دستی ندارد';
$_lang['DM_sort_noid'] = 'هیچ پرونده ای انتخاب نشده است. لطفا برگشته و پرونده ای را انتخاب کنید.';

// other tab
$_lang['DM_other_header'] = 'تنظیمات مخالف پرونده';
$_lang['DM_misc_label'] = 'تنظیمات موجود:';
$_lang['DM_misc_desc'] = 'لطفا از فهرست آبشاری تنظیم مورد نظر خود را انتخاب کنید. لطفا توجه کنید که تنها یک تنظیم در هر زمان قابل اجرا و تغییر است.';

$_lang['DM_other_dropdown_publish'] = 'انتشار/تعلیق';
$_lang['DM_other_dropdown_show'] = 'نمایش/مخفی کردن در فهرست';
$_lang['DM_other_dropdown_search'] = 'قابل جستجو/غیر قابل جستجو';
$_lang['DM_other_dropdown_cache'] = 'قابل کش/غیر قابل کش';
$_lang['DM_other_dropdown_richtext'] = 'ویرایشگر متن/بدون ویرایشگر';
$_lang['DM_other_dropdown_delete'] = 'حذف/بازگردانی';

// radio button text
$_lang['DM_other_publish_radio1'] = 'انتشار';
$_lang['DM_other_publish_radio2'] = 'تعلیق';
$_lang['DM_other_show_radio1'] = 'مخفی کردن در فهرست';
$_lang['DM_other_show_radio2'] = 'نمایش در فهرست';
$_lang['DM_other_search_radio1'] = 'قابل جستجو';
$_lang['DM_other_search_radio2'] = 'غیر قابل جستجو';
$_lang['DM_other_cache_radio1'] = 'قابل کش';
$_lang['DM_other_cache_radio2'] = 'غیر قابل کش';
$_lang['DM_other_richtext_radio1'] = 'ویرایشگر متن';
$_lang['DM_other_richtext_radio2'] = 'بدون ویرایشگر';
$_lang['DM_other_delete_radio1'] = 'حذف';
$_lang['DM_other_delete_radio2'] = 'بازگردانی';

// adjust dates
$_lang['DM_adjust_dates_header'] = 'تنظیم تاریخ پرونده ها';
$_lang['DM_adjust_dates_desc'] = 'هر یک از تنظیمات مربوط به تاریخ پرونده در زیر قابل تغییر است. بوسیله ی تنظیمات "مرور تقویم" تاریخ را تنظیم کنید.';
$_lang['DM_view_calendar'] = 'مرور تقویم';
$_lang['DM_clear_date'] = 'پاک کردن تاریخ';

// adjust authors
$_lang['DM_adjust_authors_header'] = 'تنظیم نویسنده ها';
$_lang['DM_adjust_authors_desc'] = 'از لیست آبشاری زیر نویسنده جدید را برای پرونده انتخاب کنید.';
$_lang['DM_adjust_authors_createdby'] = 'ایجاد شده توسط:';
$_lang['DM_adjust_authors_editedby'] = 'ویرایش شده توسط:';
$_lang['DM_adjust_authors_noselection'] = 'بدون تغییر';

// labels
$_lang['DM_date_pubdate'] = 'تاریخ انتشار:';
$_lang['DM_date_unpubdate'] = 'تاریخ تعلیق:';
$_lang['DM_date_createdon'] = 'ایجاد شده در تاریخ:';
$_lang['DM_date_editedon'] = 'ویرایش شده در تاریخ:';
$_lang['DM_date_notset'] = ' (بدون تنظیم)';
$_lang['DM_date_dateselect_label'] = 'انتخاب تاریخ: ';

// document select section
$_lang['DM_select_submit'] = 'ارسال';
$_lang['DM_select_range'] = 'برای انتخاب و تنظیم بازه ی پرونده به عقب برگردید';
$_lang['DM_select_range_text'] = '<p><strong>توضیح (n شناسه ی پرونده است):</strong><br /><br />
							  n* - تنظیمات برای این پرونده و اولین سری از پرونده های زیر دست اعمال شود.<br /> 
							  n** - تغییر تنظیمات برای این پرونده و کلیه پرونده های زیر دست.<br /> 
							  n-n2 - تغییرات در بازه مشخص از پرونده ها اعمال شود<br /> 
							  n - تنظیمات فقط برای همین پرونده اعمال شود</p> 
							  <p>مثال: 1*,4**,2-20,25 - این تغییرات انتخاب شده را اعمال می کند
						      برای پرونده های شماره ی 1 و زیر دستهای آن, پرونده ی 4 و همه ی زیر دستی ها آن, پرونده های 2 
						      الی 20 و پرونده ی با شناسه ی 25.</p>';
$_lang['DM_select_tree'] = 'مرور و انتخاب پرونده ها با استفاده از درختی پرونده ها';

// process tree/range messages
$_lang['DM_process_noselection'] = 'انتخابی صورت نگرفته. ';
$_lang['DM_process_novalues'] = 'هیچ مقداری مشخص نشده.';
$_lang['DM_process_limits_error'] = 'حدود بالایی کمتر از مقدار حدود پایینی است:';
$_lang['DM_process_invalid_error'] = 'مقدار اشتباه:';
$_lang['DM_process_update_success'] = 'به روز رسانی موفقیت آمیز بود, بدون هیچ ایرادی.';
$_lang['DM_process_update_error'] = 'به روز رسانی با ایراد انجام شد:';
$_lang['DM_process_back'] = 'عقب';

// manager access logging
$_lang['DM_log_template'] = 'مدیریت پرونده: پوسته و قالبها عوض شد.';
$_lang['DM_log_templatevariables'] = 'مدیریت پرونده: متغییرهای پوسته یا قالب عوض شد.';
$_lang['DM_log_docpermissions'] = 'مدیریت پرونده: سطوح دسترسی پرونده تغییر کرد.';
$_lang['DM_log_sortmenu'] = 'مدیریت پرونده: پردازش فهرست کامل شد.';
$_lang['DM_log_publish'] = 'مدیریت پرونده: تنظیمات انتشار/تعلیق پرونده ها تغییر یافت.';
$_lang['DM_log_hidemenu'] = 'مدیریت پرونده: تنظیمات مخفی کردن/نمایش در فهرست تغییر یافت.';
$_lang['DM_log_search'] = 'مدیریت پرونده: تنظیمات قابل جستجو/غیرقابل جستجو بودن پرونده ها تغییر یافت.';
$_lang['DM_log_cache'] = 'مدیریت پرونده: تنظیمات قابل کش/غیر قابل کش بودن پرونده ها تغییر یافت.';
$_lang['DM_log_richtext'] = 'مدیریت پرونده: تنظیمات مربوط به استفاده از ویرایشگر متن تغییر یافت.';
$_lang['DM_log_delete'] = 'مدیریت پرونده: تنظیمات حذف/بازگردانی پرونده ها تغییر یافت.';
$_lang['DM_log_dates'] = 'مدیریت پرونده: تنظیمات تاریخ پرونده ها تغییر یافت.';
$_lang['DM_log_authors'] = 'مدیریت پرونده: تنظیمات مربوط به نویسندگان تغییر کرد.';
?>

==> evolution-1.4.33.zip: evolution-1.4.33/assets/modules/docmanager/lang/persian.inc.php <==
<?php
/**
 * Document Manager Module
 * 
 * Purpose: Contains the language strings for use in the module.
 * Author: Garry Nutting
 * Language: English
 * Date: 2014/02/24
 */
// titles
$_lang['DM_module_title'] = 'مدیریت پرونده';
$_lang['DM_action_title'] = 'انتخاب دستور';
$_lang['DM_range_title'] = 'انتخاب بازه ی شناسه های پرونده';
$_lang['DM_tree_title'] = 'پرونده ها را از درختی انتخاب کنید';
$_lang['DM_update_title'] = 'به روز رسانی شد';
$_lang['DM_sort_title'] = 'ویرایشگر فهرست وب';

// tabs
$_lang['DM_doc_permissions'] = 'سطوح دسترسی پرونده';
$_lang['DM_template_variables'] = 'متغیرهای قالب';
$_lang['DM_sort_menu'] = 'ترتیب دهی فهرست';
$_lang['DM_change_template'] = 'تغییر پوسته یا قالب';
$_lang['DM_publish'] = 'انتشار/تعلیق';
$_lang['DM_other'] = 'مشخصات دیگر';

// buttons
$_lang['DM_close'] = 'بستن مدیریت پرونده';
$_lang['DM_cancel'] = 'بازگشت';
$_lang['DM_go'] = 'برو';
$_lang['DM_save'] = 'ذخیره';
$_lang['DM_sort_another'] = 'فهرست کردن یکی دیگه';

// templates tab
$_lang['DM_tpl_desc'] = 'قالب مورد نظر خود را از جدول زیر انتخاب کنید و سپس شناسه ی پرونده هایی که نیاز به تغییر دارند را مشخص کنید. هم میتوانید بازه ی پرونده ها را مشخص کنید و یا از درختی زیر استفاده کنید.';
$_lang['DM_tpl_no_templates'] = 'پوسته یا قلبی پیدا نشد';
$_lang['DM_tpl_column_id'] = 'شناسه';
$_lang['DM_tpl_column_name'] = 'اسم';
$_lang['DM_tpl_column_description'] = 'توضیحات';
$_lang['DM_tpl_blank_template'] = 'پوسته یا قالب خالی';
$_lang['DM_tpl_results_message'] = 'در صورتیکه نیاز به اعمال تغییرات بیشتری هستید دکمه ی هقب را بزنید. کش وبگاه بطور خودکار پاک شده.';

// template variables tab
$_lang['DM_tv_desc'] = 'شناسه ی پرونده هایی را که نیازمند تغییر است مشخص کنید, هم میتوانید از طریق مشخص کردن بازه ی شناسه انتخاب کنید و یا  از طریق درختی زیر, سپس قالب مورد نیاز را از جدل زیر انتخاب کنید تا متغیرهای قالب بازخوانی شود. مقدار متغیرهای مورد نظر خود را وارد و برای پردازش ارسال کنید.';
$_lang['DM_tv_template_mismatch'] = 'این پرونده از قالب انتخابی استفاده نمی کند.';
$_lang['DM_tv_doc_not_found'] = 'این پرونده در دیتابیس موجود نیست.';
$_lang['DM_tv_no_tv'] = 'هیچ متغیر قالبی برای این پوسته یا قالب یافت نشد.';
$_lang['DM_tv_no_docs'] = 'پرونده ای برای به روز رسانی انتخاب نشده.';
$_lang['DM_tv_no_template_selected'] = 'قالب یا پوسته ای انتخاب نشده.';
$_lang['DM_tv_loading'] = 'در حال بازخوانی متغیرهای قالب ...';
$_lang['DM_tv_ignore_tv'] = 'به این متغیرها اهمیتی داده نشود (متغیرها را با کاما جدا کنید):';
$_lang['DM_tv_ajax_insertbutton'] = 'وارد کردن';

// document permissions tab
$_lang['DM_doc_desc'] = 'گروه پرونده ای مورد نیاز را از جدول زیر انتخاب کنید. در صورت تمایل میتوانید گروه پرونده ای را اضافه یا حذف کنید. سپس شناسه ی پرونده را که بایستی تغیر کند مشخص کنید. همپنین از طریق بازه ی شناسه یا از طریق استفاده از درختی زیر.';
$_lang['DM_doc_no_docs'] = 'گروه پرونده ای یافت نشد.';
$_lang['DM_doc_column_id'] = 'شناسه';
$_lang['DM_doc_column_name'] = 'اسم';
$_lang['DM_doc_radio_add'] = 'اضافه کردن گروه پرونده ای';
$_lang['DM_doc_radio_remove'] = 'حذف گروه پرونده ای';

$_lang['DM_doc_skip_message1'] = 'پرونده با شناسه ی';
$_lang['DM_doc_skip_message2'] = 'جزو گروه پرونده ای انتخاب شده است (بی اثر)';

// other tab
$_lang['DM_other_header'] = 'تنظیمات مخالف پرونده';
$_lang['DM_misc_label'] = 'تنظیمات موجود:';
$_lang['DM_misc_desc'] = 'لطفا از فهرست آبشاری تنظیم مورد نظر خود را انتخاب کنید. لطفا توجه کنید که تنها یک تنظیم در هر زمان قابل اجرا و تغییر است.';

$_lang['DM_other_dropdown_publish'] = 'انتشار/تعلیق';
$_lang['DM_other_dropdown_show'] = 'نمایش/مخفی کردن در فهرست';
$_lang['DM_other_dropdown_search'] = 'قابل جستجو/غیر قابل جستجو';
$_lang['DM_other_dropdown_cache'] = 'قابل کش/غیر قابل کش';
$_lang['DM_other_dropdown_richtext'] = 'ویرایشگر متن/بدون ویرایشگر';
$_lang['DM_other_dropdown_delete'] = 'حذف/بازگردانی';

// radio button text
$_lang['DM_other_publish_radio1'] = 'انتشار';
$_lang['DM_other_publish_radio2'] = 'تعلیق';
$_lang['DM_other_show_radio1'] = 'مخفی کردن در فهرست';
$_lang['DM_other_show_radio2'] = 'نمایش در فهرست';
$_lang['DM_other_search_radio1'] = 'قابل جستجو';
$_lang['DM_other_search_radio2'] = 'غیر قابل جستجو';
$_lang['DM_other_cache_radio1'] = 'قابل کش';
$_lang['DM_other_cache_radio2'] = 'غیر قابل کش';
$_lang['DM_other_richtext_radio1'] = 'ویرایشگر متن';
$_lang['DM_other_richtext_radio2'] = 'بدون ویرایشگر';
$_lang['DM_other_delete_radio1'] = 'حذف';
$_lang['DM_other_delete_radio2'] = 'بازگردانی';

// adjust dates
$_lang['DM_adjust_dates_header'] = 'تنظیم تاریخ پرونده ها';
$_lang['DM_adjust_dates_desc'] = 'هر یک از تنظیمات مربوط به تاریخ پرونده در زیر قابل تغییر است. بوسیله ی تنظیمات "مرور تقویم" تاریخ را تنظیم کنید.';
$_lang['DM_view_calendar'] = 'مرور تقویم';
$_lang['DM_clear_date'] = 'پاک کردن تاریخ';

// adjust authors
$_lang['DM_adjust_authors_header'] = 'تنظیم نویسنده ها';
$_lang['DM_adjust_authors_desc'] = 'از لیست آبشاری زیر نویسنده جدید را برای پرونده انتخاب کنید.';
$_lang['DM_adjust_authors_createdby'] = 'ایجاد شده توسط:';
$_lang['DM_adjust_authors_editedby'] = 'ویرایش شده توسط:';
$_lang['DM_adjust_authors_noselection'] = 'بدون تغییر';

// labels
$_lang['DM_date_pubdate'] = 'تاریخ انتشار:';
$_lang['DM_date_unpubdate'] = 'تاریخ تعلیق:';
$_lang['DM_date_createdon'] = 'ایجاد شده در تاریخ:';
$_lang['DM_date_editedon'] = 'ویرایش شده در تاریخ:';
$_lang['DM_date_notset'] = ' (بدون تنظیم)';
$_lang['DM_date_dateselect_label'] = 'انتخاب تاریخ: ';

// document select section
$_lang['DM_select_submit'] = 'ارسال';
$_lang['DM_select_range'] = 'برای انتخاب و تنظیم بازه ی پرونده به عقب برگردید';
$_lang['DM_select_range_text'] = '<p><strong>توضیح (n شناسه ی پرونده است):</strong><br /><br />
							  n* - تنظیمات برای این پرونده و اولین سری از پرونده های زیر دست اعمال شود.<br /> 
							  n** - تغییر تنظیمات برای این پرونده و کلیه پرونده های زیر دست.<br /> 
							  n-n2 - تغییرات در بازه مشخص از پرونده ها اعمال شود<br /> 
							  n - تنظیمات فقط برای همین پرونده اعمال شود</p> 
							  <p>مثال: 1*,4**,2-20,25 - این تغییرات انتخاب شده را اعمال می کند
						      برای پرونده های شماره ی 1 و زیر دستهای آن, پرونده ی 4 و همه ی زیر دستی ها آن, پرونده های 2 
						      الی 20 و پرونده ی با شناسه ی 25.</p>';
$_lang['DM_select_tree'] = 'مرور و انتخاب پرونده ها با استفاده از درختی پرونده ها';

// process tree/range messages
$_lang['DM_process_noselection'] = 'انتخابی صورت نگرفته. ';
$_lang['DM_process_novalues'] = 'هیچ مقداری مشخص نشده.';
$_lang['DM_process_limits_error'] = 'حدود بالایی کمتر از مقدار حدود پایینی است:';
$_lang['DM_process_invalid_error'] = 'مقدار اشتباه:';
$_lang['DM_process_update_success'] = 'به روز رسانی موفقیت آمیز بود, بدون هیچ ایرادی.';
$_lang['DM_process_update_error'] = 'به روز رسانی با ایراد انجام شد:';
$_lang['DM_process_back'] = 'عقب';

// manager access logging
$_lang['DM_log_template'] = 'مدیریت پرونده: پوسته و قالبها عوض شد.';
$_lang['DM_log_templatevariables'] = 'مدیریت پرونده: متغییرهای پوسته یا قالب عوض شد.';
$_lang['DM_log_docpermissions'] = 'مدیریت پرونده: سطوح دسترسی پرونده تغییر کرد.';
$_lang['DM_log_sortmenu'] = 'مدیریت پرونده: پردازش فهرست کامل شد.';
$_lang['DM_log_publish'] = 'مدیریت پرونده: تنظیمات انتشار/تعلیق پرونده ها تغییر یافت.';
$_lang['DM_log_hidemenu'] = 'مدیریت پرونده: تنظیمات مخفی کردن/نمایش در فهرست تغییر یافت.';
$_lang['DM_log_search'] = 'مدیریت پرونده: تنظیمات قابل جستجو/غیرقابل جستجو بودن پرونده ها تغییر یافت.';
$_lang['DM_log_cache'] = 'مدیریت پرونده: تنظیمات قابل کش/غیر قابل کش بودن پرونده ها تغییر یافت.';
$_lang['DM_log_richtext'] = 'مدیریت پرونده: تنظیمات مربوط به استفاده از ویرایشگر متن تغییر یافت.';
$_lang['DM_log_delete'] = 'مدیریت پرونده: تنظیمات حذف/بازگردانی پرونده ها تغییر یافت.';
$_lang['DM_log_dates'] = 'مدیریت پرونده: تنظیمات تاریخ پرونده ها تغییر یافت.';
$_lang['DM_log_authors'] = 'مدیریت پرونده: تنظیمات مربوط به نویسندگان تغییر کرد.';
?>
